@@ -3,10 +3,13 @@ from django.template import Library, Node, Variable
 from django.template.base import TemplateSyntaxError, VariableDoesNotExist
 
 from dynamic_validation import models
+
+
 register = Library()
 
 __all__ = ('violations_for', )
 
+
 @register.tag
 def violations_for(parser, token):
     """
@@ -18,6 +21,7 @@ def violations_for(parser, token):
         raise TemplateSyntaxError("Must pass 'trigger_model as var_name' to %s tag" % bits[0])
     return ViolationsForNode(bits[1], bits[3])
 
+
 class ViolationsForNode(Node):
     def __init__(self, trigger_model, var_name):
         self.trigger_model = Variable(trigger_model)
@@ -28,5 +32,6 @@ class ViolationsForNode(Node):
             trigger_model = self.trigger_model.resolve(context)
             violations = models.Violation.objects.get_by_trigger_model(trigger_model)
             context[self.var_name] = models.ViolationsWrapper(violations)
-        except VariableDoesNotExist: pass
-        return ''
\ No newline at end of file
+        except VariableDoesNotExist:
+            pass
+        return ''
